@@ -5,8 +5,10 @@
 #include <signal.h>
 #include <fam.h>
 #include <errno.h>
+#include <error.h>
 #include <sys/stat.h>
 #include "config.h"
+#include "gettext.h"
 #include "fileschanged.h"
 #include "opts.h"
 #include "node.h"
@@ -58,17 +60,31 @@ void sigHandler( int sig)
 	else
 		signal(sig, SIG_IGN);
 }
+
+int init_locales(const char *name)
+{
+#ifdef ENABLE_NLS
+	setlocale(LC_ALL, "");
+	if (!bindtextdomain(PACKAGE_NAME, LOCALEDIR))
+		error(1,0,"Error: Couldn't bind textdomain");
+	if (!textdomain(PACKAGE_NAME))
+		error(1,0,"Error: Couldn't set textdomain");
+#endif
+	return 0;
+}
 int main(int argc, char **argv)
 {
 	int retval;
 
+	if (init_locales(PACKAGE_NAME))
+		error(1, 0, "Error: Couldn't set locale");
+
 	parse_opts(argc, argv, &arguments);
 	retval = monitor_open(&app.c);
 	if (retval != 0)
-	{
-		fprintf(stderr,"Error: Couldn't connect to fam daemon.\n");
-		exit(1);
-	}
+		error(1,0, _("Error: Couldn't connect to fam daemon."));
+
+	FAMNoExists(&app.c);
 
 	list_init(&app.list_of_files_to_monitor);
 	wl_init();
