@@ -11,15 +11,15 @@
 extern struct arguments_t arguments;
 struct handler_t handlers[FC_HANDLER_MAX]=
 {
-	{ FC_CREATED_FILE, "created", handle_created_file },
-	{ FC_CREATED_DIR, "created", handle_created_dir },
-	{ FC_CHANGED_FILE, "changed", handle_changed_file },
-	{ FC_CHANGED_DIR, "changed", handle_changed_dir },
-	{ FC_DELETED_FILE, "deleted", handle_deleted_file },
-	{ FC_DELETED_DIR, "deleted", handle_deleted_dir },
-	{ FC_STARTEXECUTING_FILE, "start-executing", 
+	{ FC_CREATED_FILE, "A", handle_created_file },
+	{ FC_CREATED_DIR, "A", handle_created_dir },
+	{ FC_CHANGED_FILE, "M", handle_changed_file },
+	{ FC_CHANGED_DIR, "M", handle_changed_dir },
+	{ FC_DELETED_FILE, "R", handle_deleted_file },
+	{ FC_DELETED_DIR, "R", handle_deleted_dir },
+	{ FC_STARTEXECUTING_FILE, "E", 
 		handle_startexecuting_file },
-	{ FC_STOPEXECUTING_FILE, "stop-executing", 
+	{ FC_STOPEXECUTING_FILE, "X", 
 		handle_stopexecuting_file },
 };
 void set_id_for_file(FAMEvent *e, enum handler_enum_t *id)
@@ -189,7 +189,7 @@ int handle_created_dir(FAMConnection *c, void *list, enum handler_enum_t id, cha
 		retval = node_new(&newdir, filename);
 		if (retval == 0)
 		{
-			printf("Adding '%s'\n",filename);
+			//printf("Adding '%s'\n",filename);
 			list_add(list,&newdir);
 			list_count(list,&count);
 			list_get_element(list,count-1,&node);
