@@ -18,7 +18,7 @@ enum handler_enum_t
 struct handler_t
 {
 	enum handler_enum_t id;
-	char *name;
+	const char *name;
 	int (*handler)(FAMConnection *c, void *list, enum handler_enum_t id, char *filename);
 };
 
