@@ -24,7 +24,7 @@ int node_new(struct node_t *node, char *filename)
 	node->filename = xrealpath(filename);
 	if (!node->filename)
 		return -2;
-	retval = stat(node->filename,&node->statbuf);
+	retval = lstat(node->filename,&node->statbuf);
 	if (retval != 0)
 	{
 		free(node->filename);
