@@ -2,50 +2,51 @@
 #include <stdlib.h>
 #include <string.h>
 #include <dlfcn.h>
+#include "gettext.h"
 #include "config.h"
 #include "opts.h"
 
 const char *argp_program_version = PACKAGE_NAME " " PACKAGE_VERSION;
 const char *argp_program_bug_address = "<" PACKAGE_BUGREPORT ">";
 
-static char doc[] = "Monitors FILEs for alterations.  "
+static char doc[] = N_("Monitors FILEs for alterations.  "
 	"Display the filenames of FILEs that were created, changed, deleted, "
 	"started execution or finished executing.\vFILEs must exist when "
-	"monitoring begins, or they will not be monitored.";
+	"monitoring begins, or they will not be monitored.");
 
-static char args_doc[] = "[FILE]...";
+static char args_doc[] = N_("[FILE]...");
 
 struct arguments_t arguments;
 
 static struct argp_option options[] = 
 {
-	{"show", 's', "EVENT[,...]", 0, 
-		"Display created, changed, deleted, executing, "
-		"or executed files (Default is \"created,changed\"" ,1},
+	{"show", 's', N_("EVENT[,...]"), 0, 
+		N_("Display created, changed, deleted, executing, "
+		"or executed files (Default is \"created,changed\")") ,1},
 	{"show-deleted", 'd', 0, OPTION_HIDDEN,
-		"Display deleted files", 1},
+		N_("Display deleted files"), 1},
 	{"show-changed", 'C', 0, OPTION_HIDDEN, 
-		"(Default) Display changed files", 1},
+		N_("(Default) Display changed files"), 1},
 	{"show-created", 'c', 0, OPTION_HIDDEN, 
-		"(Default) Display newly created files", 1},
+		N_("(Default) Display newly created files"), 1},
 	{"show-executing", 'e', 0, OPTION_HIDDEN, 
-		"Display executing files", 1},
+		N_("Display executing files"), 1},
 	{"show-executed", 'E', 0, OPTION_HIDDEN, 
-		"Display files that have stopped executing", 1},
+		N_("Display files that have stopped executing"), 1},
 	{"show-all", 'a', 0, 0, 
-		"Display all file events and the associated action", 2},
+		N_("Display all file events and the associated action"), 2},
 	{"files-to-monitor", 'f', 0, 0, 
-		"(Default) Monitor the FILEs on the command line", 3},
-	{"filelist", 'l', "FILE", 0, 
-		"Monitor the list of filenames inside FILE", 3},
+		N_("(Default) Monitor the FILEs on the command line"), 3},
+	{"filelist", 'l', N_("FILE"), 0, 
+		N_("Monitor the list of filenames inside FILE"), 3},
 	{"recursive", 'r', 0, 0, 
-		"Monitor subdirectories of directories", 4},
+		N_("Monitor subdirectories of directories"), 4},
 	{"timeout", 't', "N", 0, 
-		"Delay showing changed files for N seconds (Def=2)", 4},
+		N_("Delay showing changed files for N seconds (Def=2)"), 4},
 	{"display-action", 'p', 0, 0, 
-		"Display action when showing altered files", 5},
-	{"exec", 'x', "PROG", 0,
-		"Run PROG when file altered (PROG action filename)", 6},
+		N_("Display action when showing altered files"), 5},
+	{"exec", 'x', N_("PROG"), 0,
+		N_("Run PROG when file is altered (PROG action filename)"), 6},
 	{ 0 }
 };
 
@@ -71,22 +72,23 @@ static error_t parse_opt (int key, char *arg, struct argp_state *state)
 			for(tmp = strtok(arg, ","); tmp!=NULL;
 					tmp=strtok(NULL,","))
 			{
-				if (strcasecmp(tmp, "created") == 0)
+				if (strcasecmp(tmp, _("created")) == 0)
 					parse_opt('c', NULL, state);
-				else if (strcasecmp(tmp, "changed") == 0)
+				else if (strcasecmp(tmp, _("changed")) == 0)
 					parse_opt('C', NULL, state);
-				else if (strcasecmp(tmp, "deleted") == 0)
+				else if (strcasecmp(tmp, _("deleted")) == 0)
 					parse_opt('d', NULL, state);
-				else if (strcasecmp(tmp, "executing") == 0)
+				else if (strcasecmp(tmp, _("executing")) == 0)
 					parse_opt('e', NULL, state);
-				else if (strcasecmp(tmp, "executed") == 0)
+				else if (strcasecmp(tmp, _("executed")) == 0)
 					parse_opt('e', NULL, state);
-				else if (strcasecmp(tmp,"all")==0)
+				else if (strcasecmp(tmp,_("all"))==0)
 					parse_opt('a', NULL, state);
 				else
-					argp_failure(state, 1, 1,"Error!  '%s'"
-							"is an unrecognized "
-							"EVENT.", tmp);
+					argp_failure(state, 1, 1,_("Error!  "
+								"'%s' is an "
+							"unrecognized EVENT"
+							"."), tmp);
 			}
 			break;
 		}
