@@ -3,6 +3,8 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
+#define _(__str) gettext(__str)
+#define N_(__str) gettext_noop(__str)
 
 struct fileschanged_arguments_t
 {
